@@ -718,6 +718,19 @@ class SpannerDDLCompiler(DDLCompiler):
                 text += " STORING (%s)" % ", ".join(
                     [self.preparer.quote(c.name) for c in storing_columns]
                 )
+
+            interleave_in = options.get("interleave_in")
+            if interleave_in is not None:
+                text += f", INTERLEAVE IN {self.preparer.quote(interleave_in)}"
+
+            if options.get("null_filtered", False):
+                text = re.sub(
+                    r"(^\s*CREATE\s+(?:UNIQUE\s+)?)INDEX",
+                    r"\1NULL_FILTERED INDEX",
+                    text,
+                    flags=re.IGNORECASE,
+                )
+
         return text
 
     def get_identity_options(self, identity_options):
